@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2011-2016 Aurimas Cernius
+ * Copyright (C) 2011-2016,2019 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -26,7 +26,6 @@
 
 #include <gtkmm/modelbutton.h>
 
-#include "base/macros.hpp"
 #include "noteaddin.hpp"
 
 namespace gnote {
@@ -41,7 +40,7 @@ namespace notebooks {
     virtual void initialize() override;
     virtual void shutdown() override;
     virtual void on_note_opened() override;
-    virtual std::map<int, Gtk::Widget*> get_actions_popover_widgets() const override;
+    virtual std::vector<gnote::PopoverWidget> get_actions_popover_widgets() const override;
 
   protected:
     NotebookNoteAddin();
@@ -52,7 +51,7 @@ namespace notebooks {
     void on_new_notebook_menu_item(const Glib::VariantBase&) const;
     void on_move_to_notebook(const Glib::VariantBase &);
     void on_notebooks_changed();
-    void get_notebook_menu_items(std::list<Gtk::ModelButton*> &) const;
+    std::vector<Gtk::ModelButton*> get_notebook_menu_items() const;
     void update_menu(Gtk::Box *) const;
 
     sigc::connection          m_new_notebook_cid;
